@@ -20,28 +20,60 @@
  *
  */
 
-#include <string.h>
-#include <stdlib.h>
+#include <config.h>
+#define ___CONFIG_H__
+
+/* pppd headers *sigh* */
 #include <pppd/pppd.h>
 #include <pppd/fsm.h>
 #include <pppd/ipcp.h>
+
+#include "nm-default.h"
+
+#include <string.h>
+#include <stdlib.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <dlfcn.h>
-#include <glib.h>
-#include <gio/gio.h>
 
 #include "nm-pptp-service.h"
 #include "nm-ppp-status.h"
 
-#include <NetworkManager.h>
+#include "nm-utils/nm-shared-utils.h"
+#include "nm-utils/nm-vpn-plugin-macros.h"
 
 int plugin_init (void);
 
 char pppd_version[] = VERSION;
 
-static GDBusProxy *proxy = NULL;
+/*****************************************************************************/
+
+struct {
+	int log_level;
+	const char *log_prefix_token;
+	GDBusProxy *proxy;
+} gl/*lobal*/;
+
+/*****************************************************************************/
+
+#define _NMLOG(level, ...) \
+    G_STMT_START { \
+         if (gl.log_level >= (level)) { \
+             syslog (nm_utils_syslog_coerce_from_nm (level), \
+                     "nm-pptp[%s] %-7s [helper-%ld] " _NM_UTILS_MACRO_FIRST (__VA_ARGS__) "\n", \
+                     gl.log_prefix_token, \
+                     nm_utils_syslog_to_str (level), \
+                     (long) getpid () \
+                     _NM_UTILS_MACRO_REST (__VA_ARGS__)); \
+         } \
+    } G_STMT_END
+
+#define _LOGI(...) _NMLOG(LOG_NOTICE,  __VA_ARGS__)
+#define _LOGW(...) _NMLOG(LOG_WARNING, __VA_ARGS__)
+#define _LOGE(...) _NMLOG(LOG_ERR, __VA_ARGS__)
+
+/*****************************************************************************/
 
 static void
 nm_phasechange (void *data, int arg)
@@ -49,7 +81,7 @@ nm_phasechange (void *data, int arg)
 	NMPPPStatus ppp_status = NM_PPP_STATUS_UNKNOWN;
 	char *ppp_phase;
 
-	g_return_if_fail (G_IS_DBUS_PROXY (proxy));
+	g_return_if_fail (G_IS_DBUS_PROXY (gl.proxy));
 
 	switch (arg) {
 	case PHASE_DEAD:
@@ -110,13 +142,11 @@ nm_phasechange (void *data, int arg)
 		break;
 	}
 
-	g_message ("nm-pptp-ppp-plugin: (%s): status %d / phase '%s'",
-	           __func__,
-	           ppp_status,
-	           ppp_phase);
+	_LOGI ("phasechange: status %d / phase '%s'",
+	       ppp_status, ppp_phase);
 
 	if (ppp_status != NM_PPP_STATUS_UNKNOWN) {
-		g_dbus_proxy_call (proxy,
+		g_dbus_proxy_call (gl.proxy,
 		                   "SetState",
 		                   g_variant_new ("(u)", ppp_status),
 		                   G_DBUS_CALL_FLAGS_NONE, -1,
@@ -133,12 +163,12 @@ nm_ip_up (void *data, int arg)
 	ipcp_options peer_opts = ipcp_hisoptions[0];
 	GVariantBuilder builder;
 
-	g_return_if_fail (G_IS_DBUS_PROXY (proxy));
+	g_return_if_fail (G_IS_DBUS_PROXY (gl.proxy));
 
-	g_message ("nm-pptp-ppp-plugin: (%s): ip-up event", __func__);
+	_LOGI ("ip-up: event");
 
 	if (!opts.ouraddr) {
-		g_warning ("nm-pptp-ppp-plugin: (%s): didn't receive an internal IP from pppd!", __func__);
+		_LOGW ("ip-up: didn't receive an internal IP from pppd!");
 		nm_phasechange (NULL, PHASE_DEAD);
 		return;
 	}
@@ -196,9 +226,9 @@ nm_ip_up (void *data, int arg)
 	                       NM_VPN_PLUGIN_IP4_CONFIG_MTU,
 	                       g_variant_new_uint32 (1400));
 
-	g_message ("nm-pptp-ppp-plugin: (%s): sending Ip4Config to NetworkManager-pptp...", __func__);
+	_LOGI ("ip-up: sending Ip4Config to NetworkManager-pptp...");
 
-	g_dbus_proxy_call (proxy,
+	g_dbus_proxy_call (gl.proxy,
 	                   "SetIp4Config",
 	                   g_variant_new ("(a{sv})", &builder),
 	                   G_DBUS_CALL_FLAGS_NONE, -1,
@@ -225,7 +255,7 @@ get_credentials (char *username, char *password)
 	const char *my_password = NULL;
 	size_t len;
 	GVariant *ret;
-	GError *err = NULL;
+	GError *error = NULL;
 
 	if (!password) {
 		/* pppd is checking pap support; return 1 for supported */
@@ -234,25 +264,23 @@ get_credentials (char *username, char *password)
 	}
 
 	g_return_val_if_fail (username, -1);
-	g_return_val_if_fail (G_IS_DBUS_PROXY (proxy), -1);
+	g_return_val_if_fail (G_IS_DBUS_PROXY (gl.proxy), -1);
 
-	g_message ("nm-pptp-ppp-plugin: (%s): passwd-hook, requesting credentials...", __func__);
+	_LOGI ("passwd-hook: requesting credentials...");
 
-	ret = g_dbus_proxy_call_sync (proxy,
+	ret = g_dbus_proxy_call_sync (gl.proxy,
 	                              "NeedSecrets",
 	                              NULL,
 	                              G_DBUS_CALL_FLAGS_NONE, -1,
-	                              NULL, &err);
+	                              NULL, &error);
 	if (!ret) {
-		g_warning ("nm-pptp-ppp-plugin: (%s): could not get secrets: (%d) %s",
-		           __func__,
-		           err ? err->code : -1,
-		           err->message ? err->message : "(unknown)");
-		g_error_free (err);
+		_LOGW ("passwd-hook: could not get secrets: %s",
+		       error->message);
+		g_error_free (error);
 		return -1;
 	}
 
-	g_message ("nm-pptp-ppp-plugin: (%s): got credentials from NetworkManager-pptp", __func__);
+	_LOGI ("passwd-hook: got credentials from NetworkManager-pptp");
 
 	g_variant_get (ret, "(&s&s)", &my_username, &my_password);
 
@@ -280,54 +308,55 @@ get_credentials (char *username, char *password)
 static void
 nm_exit_notify (void *data, int arg)
 {
-	g_return_if_fail (G_IS_DBUS_PROXY (proxy));
+	g_return_if_fail (G_IS_DBUS_PROXY (gl.proxy));
 
-	g_message ("nm-pptp-ppp-plugin: (%s): cleaning up", __func__);
-
-	g_object_unref (proxy);
-	proxy = NULL;
+	_LOGI ("exit: cleaning up");
+	g_clear_object (&gl.proxy);
 }
 
 int
 plugin_init (void)
 {
 	GDBusConnection *bus;
-	GError *err = NULL;
+	GError *error = NULL;
 	const char *bus_name;
 
-#if !GLIB_CHECK_VERSION (2, 35, 0)
-	g_type_init ();
-#endif
+	nm_g_type_init ();
+
+	g_return_val_if_fail (!gl.proxy, -1);
 
 	bus_name = getenv ("NM_DBUS_SERVICE_PPTP");
 	if (!bus_name)
 		bus_name = NM_DBUS_SERVICE_PPTP;
 
-	g_message ("nm-pptp-ppp-plugin: (%s): initializing", __func__);
+	gl.log_level = _nm_utils_ascii_str_to_int64 (getenv ("NM_VPN_LOG_LEVEL"),
+	                                             10, 0, LOG_DEBUG,
+	                                             LOG_NOTICE);
+	gl.log_prefix_token = getenv ("NM_VPN_LOG_PREFIX_TOKEN") ?: "???";
 
-	bus = g_bus_get_sync (G_BUS_TYPE_SYSTEM, NULL, &err);
+	_LOGI ("initializing");
+
+	bus = g_bus_get_sync (G_BUS_TYPE_SYSTEM, NULL, &error);
 	if (!bus) {
-		g_warning ("nm-pptp-pppd-plugin: (%s): couldn't connect to system bus: (%d) %s",
-		           __func__,
-		           err ? err->code : -1,
-		           err && err->message ? err->message : "(unknown)");
-		g_error_free (err);
+		_LOGE ("couldn't connect to system bus: %s",
+		       error->message);
+		g_error_free (error);
 		return -1;
 	}
 
-	proxy = g_dbus_proxy_new_sync (bus,
-	                               G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
-	                               NULL,
-	                               NM_DBUS_SERVICE_PPTP_PPP,
-	                               bus_name,
-	                               NM_DBUS_INTERFACE_PPTP_PPP,
-	                               NULL, &err);
+	gl.proxy = g_dbus_proxy_new_sync (bus,
+	                                  G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
+	                                  NULL,
+	                                  bus_name,
+	                                  NM_DBUS_PATH_PPTP_PPP,
+	                                  NM_DBUS_INTERFACE_PPTP_PPP,
+	                                  NULL, &error);
 	g_object_unref (bus);
 
-	if (!proxy) {
-		g_warning ("nm-pptp-pppd-plugin: (%s): couldn't create D-Bus proxy: %s",
-		           __func__, err->message);
-		g_error_free (err);
+	if (!gl.proxy) {
+		_LOGE ("couldn't create D-Bus proxy: %s",
+		       error->message);
+		g_error_free (error);
 		return -1;
 	}
 
@@ -338,7 +367,6 @@ plugin_init (void)
 
 	add_notifier (&phasechange, nm_phasechange, NULL);
 	add_notifier (&ip_up_notifier, nm_ip_up, NULL);
-	add_notifier (&exitnotify, nm_exit_notify, proxy);
-
+	add_notifier (&exitnotify, nm_exit_notify, NULL);
 	return 0;
 }
